# National Hydrography Dataset (NHD)

The National Hydrography Dataset (NHD) represents the water drainage network of the United States with features such as rivers, streams, canals, lakes, ponds, coastline, dams, and streamgages. The National Hydrography Dataset (NHD) is mapped at 1:24,000 or larger scale (1:63,360 or larger scale in Alaska). These data are updated and maintained through [Stewardship](https://www.usgs.gov/national-hydrography/stewardship-and-community) partnerships with states and other collaborative bodies ([source](https://www.usgs.gov/national-hydrography/national-hydrography-dataset))

The NHD is a national framework for assigning reach addresses to water-related entities, such as industrial discharges, drinking water supplies, fish habitat areas, wild and scenic rivers. Furthermore, because the NHD provides a nationally consistent framework for addressing and analysis, water-related information linked to reach addresses by one organization (national, state, local) can be shared with other organizations and easily integrated into many different types of applications to the benefit of all. You can find the [dataset and additional links here](https://www.usgs.gov/national-hydrography)

#### Data Citation
You can find citation [information here](https://www.usgs.gov/faqs/how-should-i-cite-datasets-and-services-national-map). The USGS recommends the user to follow guidelines from the journal in question.

Citation example

```
U.S. Geological Survey, 2022, National Hydrography Dataset (ver. USGS National Hydrography Dataset Best Resolution (NHD) for Hydrologic Unit (HU) 4 - 2001 (published 20191002)), accessed April 29, 2022 at URL https://www.usgs.gov/national-hydrography/access-national-hydrography-products
```

#### Dataset Descriptions

- **NHDFlowline**: consists of StreamRiver, CanalDitch, Pipeline, Underground Conduit, Artificial Path, Connector, and Coastline.
- **NHDWaterbody**: consists of LakePond, SwampMarsh, Reservoir, Playa, Ice Mass, and Estuary.
- **NHDArea**: includes Area of Complex Channel, Area To Be Submerged, BayInlet, Bridge, CanalDitch, DamWeir, Flume, Foreshore, Inundation Area, Levee, Lock Chamber, Rapids, SeaOcean, Spillway, StreamRiver, Submerged Stream, Wash, Water Intake/Outflow. Having CanalDitch and StreamRiver in this class seems inconsistent, but there is a good reason for this because we need both polygon and line forms of geography.
- **NHDLine**: includes Area of Complex Channel, Area To Be Submerged, BayInlet, Bridge, CanalDitch, DamWeir, Flume, Foreshore, Inundation Area, Levee, Lock Chamber, Rapids, SeaOcean, Spillway, StreamRiver, Submerged Stream, Wash, Water Intake/Outflow. Having CanalDitch and StreamRiver in this class seems inconsistent, but there is a good reason for this because we need both polygon and line forms of geography.
- **NHDPoint**: includes DamWeir, Gaging Station, Gate, Lock Chamber, Rapids, Reservoir, Rock, SinkRise, SpringSeep, Waterfall, Water Intake/Outflow, and Well.
- **NHDPointEventFC**: point events located on NHDFlowlines.
- **NHDLineEventFC**: line events located on NHDFlowlines.
- **NHDAreaEventFC**: area events located on NHDWaterbody.
- **WBDHU10**: polygon for HU10
- **WBDHU12**: polygon for HU12
- **WBDHU14**: polygon for HU14
- **WBDHU16**: polygon for HU16
- **WBDHU2**: polygon for HU2
- **WBDHU4**: polygon for HU4
- **WBDHU6**: polygon for HU6
- **WBDHU8**: polygon for HU8
- **WBDLine**: individual lines used in WBD polygons

#### Data preprocessing
individual shapefiles pertaining to each dataset within a state is ingested to Google Earth Engine. It seems that the flowline features were split for large areas and as such to avoid the use having to combine multiple collections and flatten, a flattened joined NHDFlowline layer has been provided for each state. Each state has it's own sub folder and as such we recommend using the state abbreviations to get to the state of choice. Overall list of all states can be generated by simply using the earthengine command line

```
earthengine ls "projects/sat-io/open-datasets/NHD"
```

![nhd](https://user-images.githubusercontent.com/6677629/166146991-c05e0e5c-876c-41e1-a289-9cc7b3a9dbc0.gif)


#### Dataset structure
The datasets are arranged by state abbreviations, so to get to a specific state simply replace state abbreviation

Example Path: projects/sat-io/open-datasets/NHD/NHD_AK


#### Earth Engine Snippet
Sample example for state Missouri with state abbreviation MO
```js
var nhd_area = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/NHDArea");
var nhd_flowline = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/NHDFlowline");
var nhd_line = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/NHDLine");
var nhd_point = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/NHDPoint");
var nhd_point_event_fc = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/NHDPointEventFC");
var nhd_waterbody = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/NHDWaterbody");
var nhd_wbdhu10 = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/WBDHU10");
var nhd_wbdhu12 = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/WBDHU12");
var nhd_wbdhu14 = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/WBDHU14");
var nhd_wbdhu2 = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/WBDHU2");
var nhd_wbdhu4 = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/WBDHU4");
var nhd_wbdhu6 = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/WBDHU6");
var nhd_wbdhu8 = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/WBDHU8");
var nhd_wbdline = ee.FeatureCollection("projects/sat-io/open-datasets/NHD/NHD_MO/WBDLine");
```

Sample code: https://code.earthengine.google.com/?scriptPath=users/sat-io/awesome-gee-catalog-examples:hydrology/NATIONAL-HYDROGRAPHY-DATASET


#### License
The NHD data is distributed under a license similar to Public domain license and distributed by United States Geological Survey (USGS)

Created by: United States Geological Survey (USGS)

Curated in GEE by : Samapriya Roy

Keywords: Hydrography, Hydrologic, United States, USGS, NHD, National Hydrography Dataset

Last updated on GEE: 2022-05-04


#### Data changelog

* Fixed property field permanent post reprocessing entire dataset and change field permanent_id listed as Permanent_ to permanent for reference.
* Merged all flowlines and waterbodies to be single objects
