# National Wetland Inventory (Surface Water and Wetlands)

The US Fish and Wildlife Service (FWS) is the principal US Federal agency tasked with providing information to the public on the status and trends of our Nation's wetlands. Wetlands provide a multitude of ecological, economic and social benefits. They provide habitat for fish, wildlife and plants - many of which have a commercial or recreational value - recharge groundwater, reduce flooding, provide clean drinking water, offer food and fiber, and support cultural and recreational activities. Unfortunately, over half of America’s wetlands have been lost since 1780, and wetland losses continue today. This highlights the urgent need for geospatial information on wetland extent, type, and change. The US FWS National Wetlands Inventory (NWI) is a publicly available resource that provides detailed information on the abundance, characteristics, and distribution of US wetlands. NWI data are used by natural resource managers, within the US FWS and throughout the Nation, to promote the understanding, conservation and restoration of wetlands. You can download the [dataset here](https://www.fws.gov/wetlands/data/data-download.html).

#### Dataset and GEE reference

|Layer Name                            |GEE_Folder_Prefix|Description                                                                                                                                                                                                                                                          |
|--------------------------------------|-----------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|NWI Historic Wetlands                 |historic_wetlands|This data set represents the extent and approximate location of historic wetland habitats in certain areas of the conterminous United States                                                                                                                         |
|NWI Historic Wetlands Project Metadata|hwpm             |This data set represents the extent, status, and location of current NWI historic wetland mapping projects.                                                                                                                                                          |
|NWI Wetlands                          |wetlands         |This data set represents the extent, approximate location and type of wetlands and deepwater habitats in the United States and its Territories                                                                                                                       |
|NWI Wetlands Project Metadata         |wpm              |This data set represents the extent, status, and location of National Wetland Inventory wetland mapping projects for NWI Version 2, Surface Waters and Wetlands                                                                                                      |
|NWI Riparian Areas                    |riparian         |This data set represents the extent, approximate location and type of riparian habitats in the western United States.  These data delineate the areal extent of riparian habitats as defined by a System For Mapping Riparian Areas in the United States (USFWS 2009)|
|NWI Riparian Project Metadata         |rpm              |This data set represents the extent, status, and location of current NWI riparian mapping projects                                                                                                                                                                   |
|NWI Wetlands Historic Map Info        |hmi              |This data set represents the extent and location of historic wetland map reports generated by the U.S. Fish and Wildlife Service, cooperators, and contractors                                                                                                       |

![nwi](https://user-images.githubusercontent.com/6677629/133915552-ae43c627-581d-4f9e-a4a1-6193d4e9f385.gif)

#### Data Preprocessing
The datasets are provided by states and some states are split into multiparts. The shapefile consists of multiple geometry types including but not limited to points an linestring apart from polygons and multipolygons. Attempt was made to combine multiple parts from each state into a single feature collection within earthengine, since GEE will not work with a zero area object during a featurecollection export, a filter was created to tag each feature type and calculate area. Also zero area features were then excluded. Currently the wetlands datasets is the only one where this transformation was applied.

Currently these wetlands files are complete and are present in the folder with naming State-Abbreviation_Wetlands so for example for Florida , FL_Wetlands and so on. Other datasets are not present for all states and you can get a list of assets by simply running an ```earthengine ls``` on the objects or by using the catalog. Since this is an immensely large dataset collection, no attempt was made to create a country wide composite. A single JSON file is also created to allow you to asses which datasets contain which state as an easy reference, [you can find it here](https://gist.githubusercontent.com/samapriya/6263500764bdaef178b0c16ef6849104/raw/8031ca02f0509e82f4908d7a14d68d2b97d93771/nwi_assets.json).


#### Suggested Citation

(dataset) U.S. Fish & Wildlife Service. (2018). National Wetlands Inventory. U.S. Fish & Wildlife Service. https://data.nal.usda.gov/dataset/national-wetlands-inventory. Accessed 2021-09-19.

#### Earth Engine Snippet

The dataset templates underneath can be simply replaced by the state code/territory code to get to the state/region of interest.

```js
var wetlands = ee.FeatureCollection("projects/sat-io/open-datasets/NWI/wetlands/FL_Wetlands");
var historic_wetland = ee.FeatureCollection("projects/sat-io/open-datasets/NWI/historic_wetlands/FL_Historic_Wetlands");
var historic_wetland_project_metadata = ee.FeatureCollection("projects/sat-io/open-datasets/NWI/hwpm/FL_Historic_Wetlands_Project_Metadata");
var historic_map_info = ee.FeatureCollection("projects/sat-io/open-datasets/NWI/hmi/FL_Wetlands_Historic_Map_Info");
var co_riparian = ee.FeatureCollection("projects/sat-io/open-datasets/NWI/riparian/CO_Riparian");
var co_riparian_metadata = ee.FeatureCollection("projects/sat-io/open-datasets/NWI/rpm/CO_Riparian_Project_Metadata");
var wetlands_metadata = ee.FeatureCollection("projects/sat-io/open-datasets/NWI/wpm/FL_Wetlands_Project_Metadata");
```

Sample code: https://code.earthengine.google.com/?scriptPath=users/sat-io/awesome-gee-catalog-examples:hydrology/NATIONAL-WETLANDS-INVENTORY


#### Wetlands Layer Legend

Wetland types are displayed on the Wetlands Mapper in groups of similar classifications (e.g. all freshwater emergent wetlands are displayed as a single color category). The display categories are shown in the table below. Display color codes are provided for those looking to create their own maps using the Mapper color scheme.

<center>

<table width="500" border="1">
	<tr bgcolor="#008837">
		<td>#008837</td>
    <td>Freshwater- Forested and Shrub wetland</td>
	</tr>

	<tr bgcolor="#7FC31C">
    <td>#7FC31C</td>
		<td>Freshwater Emergent wetland</td>
	</tr>

  <tr bgcolor="#688CC0">
    <td>#688CC0</td>
		<td>Freshwater pond</td>
	</tr>

	<tr bgcolor="#66C2A5">
    <td>#66C2A5</td>
		<td>Estuarine and Marine wetland</td>
	</tr>
  <tr bgcolor="#0190BF">
    <td>#0190BF</td>
		<td>Riverine</td>
	</tr>

	<tr bgcolor="#13007C">
    <td>#13007C</td>
		<td>Lakes</td>
	</tr>

  <tr bgcolor="#007C88">
    <td>#007C88</td>
		<td>Estuarine and Marine Deepwater</td>
	</tr>

	<tr bgcolor="#B28653">
    <td>#B28653</td>
		<td>Other Freshwater wetland</td>
	</tr>

</table>

</center>


#### License

The US FWS National Wetlands Inventory (NWI) is a publicly available resource that provides detailed information on the abundance, characteristics, and distribution of US. NWI datasets are freely available to the public (similar to a CC0 license) and the U.S. Public Domain license.

Created by: U.S. Fish and Wildlife Service

Curated by: Samapriya Roy

Keywords: wetlands, conservation areas, habitats, fish, wildlife, drinking water, recreation, U.S. Fish and Wildlife Service

Last updated: 2021-09-19
