# Normalized Sentinel-1 Global Backscatter Model Land Surface

This dataset was generated by the Remote Sensing Group of the [TU Wien Department of Geodesy and Geoinformation](https://mrs.geo.tuwien.ac.at/), within a dedicated project by the European Space Agency (ESA). The Sentinel-1 Global Backscatter Model (S1GBM) describes Earth for the period 2016-17 by the mean C-band radar cross section in VV- and VH-polarization at a 10 m sampling, giving a high-quality impression on surface- structures and -patterns. The Sentinel-1 Global Backscatter Model (S1GBM) describes Earth for the period 2016–17 by the mean C-band radar cross section in VV- and VH-polarisation at a 10 m sampling. The TU Wein center processed 0.5 million Sentinel-1 scenes totaling 1.1 PB and performed semi-automatic quality curation and backscatter harmonisation related to orbit geometry effects.

![preview_img](https://user-images.githubusercontent.com/6677629/140654171-7a818aa3-312c-43e9-bf68-e0fd5bcb6128.png)

The overall mosaic quality excels (the few) existing datasets, with minimised imprinting from orbit discontinuities and successful angle normalisation in large parts of the world. Supporting the design and verification of upcoming radar sensors, the obtained S1GBM data potentially also serve land cover classification and determination of vegetation and soil states, as well as water body mapping. You can [read the full paper which is open source here](https://www.nature.com/articles/s41597-021-01059-7). The authors further introduce the use of [Equi7Grid](https://www.sciencedirect.com/science/article/pii/S0098300414001629) for distribution of the dataset which is a high resolution optimized global grid for distribution of data.

#### Citation

```
Bauer-Marschallinger, Bernhard, Senmao Cao, Claudio Navacchi, Vahid Freeman, Felix Reuß, Dirk Geudtner, Björn Rommen et al. "The normalised
Sentinel-1 Global Backscatter Model, mapping Earth’s land surface with C-band microwaves." Scientific Data 8, no. 1 (2021): 1-18.
```

#### Dataset Record
The VV and VH mosaics are sampled at 10 m pixel spacing, georeferenced to the Equi7Grid and divided into six continental zones (Africa, Asia, Europe, North America, Oceania, South America), which are further divided into square tiles of 100 km extent ("T1"-tiles). With this setup, the S1GBM consists of 16071 tiles over six continents, for VV and VH each, totaling to a compressed data volume of 2.67 TB. The files were distributed as aggregated zipfiles with a total of 12 zip files.

The tiles' file-format is a LZW-compressed GeoTIFF holding 16-bit integer values, with tagged metadata on encoding and georeference. Compatibility with common geographic information systems as QGIS or ArcGIS, and geodata libraries as GDAL is given.

#### GEE Pre Processing
The main file rather than the preview files are ingested and file name is used to create the complete metadata structure for each of these tiled images. While all attempts were made for completeness of tiles, the extremely large volume of each zipfile caused multiple failed attempts and broken link issues. However attempts were made to retry for failures at both download and ingest stages into GEE.

A filename of one tile of a mosaic may be for example:

```
M20160104_20171230_TMENSIG38_S1-IWGRDH1VH-_——_B0104_NA010M_E064N036T1.tif
```

It defines the following:

* "M" for the actual main data, or “Q” for the quicklook-file (for preview, see below).

* start- and end-time of input data to this mosaic tile, in the format YYYYMMDD

* the aggregated statistical parameter; for Version 1.0 this is always “TMENSIG38”, i.e. mean of backscatter normalised to 38°

* relating to the input data, the satellite and sensor mode identifier “S1-IWGRDH1”, abbreviating Sentinel-1 Interferometric Wide Swath mode that is Ground Range Detected at High-resolution

* the backscatter polarisation; so "VV" or "VH"

* the version of TU Wien’s internal processing engine, i.e. "B0104"

* the identifier for Equi7Grid’s continental grid, with pixel sampling in meters, e.g., "NA010M" for North America and 10 m pixel size

* the identifier for Equi7Grid’s tile within the continent, defined by the lower left coordinate, and the tile extent; e.g. "E064N036" for 6400 km easting and 3600 km northing, and "T1" for 100 km tile extent to the east and north


![equi7grid](https://user-images.githubusercontent.com/6677629/140654058-1b3553f5-56dc-4f7e-90f9-4104500a619e.gif)

#### Earth Engine Snippet: Equi7Grid

```js
var AF_T1 = ee.FeatureCollection("projects/sat-io/open-datasets/equi7grid/EQUI7_V14_AF_GEOG_TILE_T1");
var AN_T1 = ee.FeatureCollection("projects/sat-io/open-datasets/equi7grid/EQUI7_V14_AN_GEOG_TILE_T1");
var AS_T1 = ee.FeatureCollection("projects/sat-io/open-datasets/equi7grid/EQUI7_V14_AS_GEOG_TILE_T1");
var EU_T1 = ee.FeatureCollection("projects/sat-io/open-datasets/equi7grid/EQUI7_V14_EU_GEOG_TILE_T1");
var NA_T1 = ee.FeatureCollection("projects/sat-io/open-datasets/equi7grid/EQUI7_V14_NA_GEOG_TILE_T1");
var OC_T1 = ee.FeatureCollection("projects/sat-io/open-datasets/equi7grid/EQUI7_V14_OC_GEOG_TILE_T1");
var SA_T1 = ee.FeatureCollection("projects/sat-io/open-datasets/equi7grid/EQUI7_V14_SA_GEOG_TILE_T1");
```

Sample Code Equi7Grid: https://code.earthengine.google.com/?scriptPath=users/sat-io/awesome-gee-catalog-examples:geophysical-biological-biogeochemical/EQUI7-GRID

![backscatter](https://user-images.githubusercontent.com/6677629/140654055-383c84eb-926c-47b7-8615-fe74396439f3.gif)

#### Earth Engine Snippet

```js
var VH = ee.ImageCollection("projects/sat-io/open-datasets/S1GBM/normalized_s1_backscatter_VH");
var VV = ee.ImageCollection("projects/sat-io/open-datasets/S1GBM/normalized_s1_backscatter_VV");
```

Sample code: https://code.earthengine.google.com/?scriptPath=users/sat-io/awesome-gee-catalog-examples:geophysical-biological-biogeochemical/S1-GLOBAL-BACKSCATTER


#### Web-Based Data Viewer
The layer is also made available for visualization from Earth Observation Data Centre (EODC) under http://s1map.eodc.eu/.


#### License
This work is licensed under a Creative Commons Attribution 4.0 International License. You are free to copy and redistribute the material in any medium or format, and to transform and build upon the material for any purpose, even commercially. You must give appropriate credit, provide a link to the license, and indicate if changes were made.

Curated by: Bernhard et al, European Space Agency

Keywords: Mosaic, Sentinel-1, Backscatter, Normalized, VV, VH, polarization, S1GBM, European Space Agency, ESA

Last data update: 2021-10-26

Last updated on GEE: 2021-11-07
