# Archival NRT FIRMS Global VIIRS and MODIS vector data

The Visible Infrared Imaging Radiometer Suite (VIIRS) 375 m thermal anomalies / active fire product provides data from the VIIRS sensor aboard the joint NASA/NOAA Suomi National Polar-orbiting Partnership (Suomi NPP) and NOAA-20 satellites. The 375 m data complements Moderate Resolution Imaging Spectroradiometer (MODIS) fire detection; they both show good agreement in hotspot detection but the improved spatial resolution of the 375 m data provides a greater response over fires of relatively small areas and provides improved mapping of large fire perimeters. The 375 m data also has improved nighttime performance. Consequently, these data are well suited for use in support of fire management (e.g., near real-time alert systems), as well as other science applications requiring improved fire mapping fidelity.

VIIRS NRT 375 m active fire products are from: Suomi NPP (VNP14IMGTDL_NRT) and NOAA-20, formally known as JPSS-1, (VJ114IMGTDL_NRT).

#### Notes

* In an effort to standardize VIIRS file names from Suomi NPP, the short name for VIIRS NRT 375 m product was changed from VNP14IMGT to VNP14IMGTDL_NRT (18 April 2016).
* MODIS C61 is available from November 2000 (for Terra) and from July 2002 (for Aqua) to the present.
* VIIRS 375 m data are currently available from 20 January 2012 to the present.
* Low confidence nighttime pixels occur only over the geographic area extending from 11deg E to 110 deg W and 7 deg N to 55 deg S. This area describes the region of influence of the South Atlantic Magnetic Anomaly which can cause spurious brightness temperatures in the mid-infrared channel I4 leading to potential false positive alarms. These have been removed from the NRT data distributed by FIRMS.

Archival data was downloaded for each year and ingested as shapefiles. You can [download the archives here](https://firms.modaps.eosdis.nasa.gov/download/)


You can read more about the [MODIS product here](https://earthdata.nasa.gov/earth-observation-data/near-real-time/firms/mcd14dl) and the [VIIRS product here](https://earthdata.nasa.gov/earth-observation-data/near-real-time/firms/viirs-i-band-active-fire-data)


#### Citations

```
NRT VIIRS 375 m Active Fire product VJ114IMGTDL_NRT distributed from NASA FIRMS. Available on-line [https://earthdata.nasa.gov/firms]. doi: 10.5067/FIRMS/VIIRS/VJ114IMGT_NRT.002
```

```
NRT VIIRS 375 m Active Fire product VNP14IMGT distributed from NASA FIRMS. Available on-line [https://earthdata.nasa.gov/firms].  doi:10.5067/FIRMS/VIIRS/VNP14IMGT_NRT.002
```

```
MODIS Collection 61 NRT Hotspot / Active Fire Detections MCD14DL distributed from NASA FIRMS.Available on-line [https://earthdata.nasa.gov/firms]. 10.5067/FIRMS/MODIS/MCD14DL.NRT.0061
```

```
MODIS Collection 6 Hotspot / Active Fire Detections MCD14ML distributed from NASA FIRMS. Available on-line [https://earthdata.nasa.gov/firms]. doi: 10.5067/FIRMS/MODIS/MCD14ML
```

#### Attribute fields for NRT VIIRS 375 m active fire data distributed by FIRMS

|Attribute |Short Description              |Long Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
|----------|-------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|Latitude  |Latitude                       |Center of nominal 375 m fire pixel                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|Longitude |Longitude                      |Center of nominal 375 m fire pixel                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|Bright_ti4|Brightness temperature I-4     |VIIRS I-4 channel brightness temperature of the fire pixel measured in Kelvin.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|Scan      |Along Scan pixel size          |The algorithm produces approximately 375 m pixels at nadir. Scan and track reflect actual pixel size.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|Track     |Along Track pixel size         |The algorithm produces approximately 375 m pixels at nadir. Scan and track reflect actual pixel size.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|Acq_Date  |Acquisition Date               |Date of VIIRS acquisition.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|Acq_Time  |Acquisition Time               |Time of acquisition/overpass of the satellite (in UTC).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|Satellite |Satellite                      |N= Suomi National Polar-orbiting Partnership (Suomi NPP), 1=NOAA-20 (designated JPSS-1 prior to launch)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|Confidence|Confidence                     |This value is based on a collection of intermediate algorithm quantities used in the detection process. It is intended to help users gauge the quality of individual hotspot/fire pixels. Confidence values are set to low, nominal and high. Low confidence daytime fire pixels are typically associated with areas of sun glint and lower relative temperature anomaly (<15K) in the mid-infrared channel I4. Nominal confidence pixels are those free of potential sun glint contamination during the day and marked by strong (>15K) temperature anomaly in either day or nighttime data. High confidence fire pixels are associated with day or nighttime saturated pixels.                                                                                                                                                                                                                                                                                              |
|Version   |Version (Collection and source)|Version identifies the collection (e.g. VIIRS Collection 1) and source of data processing: Near Real-Time (NRT suffix added to collection) or Standard Processing (collection only). "1.0NRT" - Collection 1 NRT processing, "1.0" - Collection 1 Standard processing                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|Bright_ti5|Brightness temperature I-5     |I-5 Channel brightness temperature of the fire pixel measured in Kelvin.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|FRP       |Fire Radiative Power           |FRP depicts the pixel-integrated fire radiative power in MW (megawatts). FRP depicts the pixel-integrated fire radiative power in MW (megawatts). Given the unique spatial and spectral resolution of the data, the VIIRS 375 m fire detection algorithm was customized and tuned in order to optimize its response over small fires while balancing the occurrence of false alarms. Frequent saturation of the mid-infrared I4 channel (3.55-3.93 µm) driving the detection of active fires requires additional tests and procedures to avoid pixel classification errors. As a result, sub-pixel fire characterization (e.g., fire radiative power [FRP] retrieval) is only viable across small and/or low-intensity fires. Systematic FRP retrievals are based on a hybrid approach combining 375 and 750 m data. In fact, starting in 2015 the algorithm incorporated additional VIIRS channel M13 (3.973-4.128 µm) 750 m data in both aggregated and unaggregated format.|
|DayNight  |Day or Night                   |D= Daytime fire, N= Nighttime fire                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |

#### Attribute fields for MCD14ML (standard quality) data active fire data distributed by FIRMS

|Attribute |Short Description              |Long Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
|----------|-------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|Latitude  |Latitude                       |Center of 1km fire pixel but not necessarily the actual location of the fire as one or more fires can be detected within the 1km pixel.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|Longitude |Longitude                      |Center of 1km fire pixel but not necessarily the actual location of the fire as one or more fires can be detected within the 1km pixel.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|Brightness|Brightness temperature 21 (Kelvin)|Channel 21/22 brightness temperature of the fire pixel measured in Kelvin.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|Scan      |Along Scan pixel size          |The algorithm produces 1km fire pixels but MODIS pixels get bigger toward the edge of scan. Scan and track reflect actual pixel size.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|Track     |Along Track pixel size         |The algorithm produces 1km fire pixels but MODIS pixels get bigger toward the edge of scan. Scan and track reflect actual pixel size.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|Acq_Date  |Acquisition Date               |Data of MODIS acquisition.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|Acq_Time  |Acquisition Time               |Time of acquisition/overpass of the satellite (in UTC).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|Satellite |Satellite                      |A = Aqua and T = Terra.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|Confidence|Confidence (0-100%)            |This value is based on a collection of intermediate algorithm quantities used in the detection process. It is intended to help users gauge the quality of individual hotspot/fire pixels. Confidence estimates range between 0 and 100% and are assigned one of the three fire classes (low-confidence fire, nominal-confidence fire, or high-confidence fire).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|Version   |Version (Collection and source)|Version identifies the collection (e.g. MODIS Collection 6) and source of data processing: Near Real-Time (NRT suffix added to collection) or Standard Processing (collection only). "6.1NRT" - Collection 61 NRT processing,  "6.1" - Collection 61 Standard processing                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|Bright_T31|Brightness temperature 31 (Kelvin)|Channel 31 brightness temperature of the fire pixel measured in Kelvin.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|FRP       |Fire Radiative Power (MW - megawatts)|Depicts the pixel-integrated fire radiative power in MW (megawatts).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
|Type*     |Inferred hot spot type         |0 = presumed vegetation fire,1 = active volcano, 2 = other static land source, 3 = offshore                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|DayNight  |Day or Night                   |D= Daytime fire, N= Nighttime fire                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |


![viirs_fire](https://user-images.githubusercontent.com/6677629/165755907-63396aff-10c6-4071-9453-14823a478727.gif)

#### Dataset structure
The MODIS and VIIRS yearly exports were ingested and names based on their years (MODIS 2000-2020) and (VIIRS 2012-2021)

MODIS Path: projects/sat-io/open-datasets/MODIS_MCD14DL/MCD14DL_YYYY
Example Path: projects/sat-io/open-datasets/MODIS_MCD14DL/MCD14DL_2000

VIIRS Path: projects/sat-io/open-datasets/VIIRS/VNP14IMGTDL_NRT_YYYY
Example Path: projects/sat-io/open-datasets/VIIRS/VNP14IMGTDL_NRT_2012

#### Earth Engine Snippet

Sample paths are provided for two years only change the year to get different years

```js
var viirs_2012 = ee.FeatureCollection("projects/sat-io/open-datasets/VIIRS/VNP14IMGTDL_NRT_2012");
var modis_2012 = ee.FeatureCollection("projects/sat-io/open-datasets/MODIS_MCD14DL/MCD14DL_2012");
```

Sample code: https://code.earthengine.google.com/?scriptPath=users/sat-io/awesome-gee-catalog-examples:global-events-layers/ARCHIVAL-NRT-FIRMS-VIIRS-DATA


#### License
The FIRMS data is distributed under a license similar to Public domain license and distributed by Land, Atmosphere Near real-time Capability for EOS (LANCE) for Fire Information for Resource Management System (FIRMS)

#### Acknowledgements
We acknowledge the use of data and/or imagery from NASA's Fire Information for Resource Management System (FIRMS) (https://earthdata.nasa.gov/firms), part of NASA's Earth Observing System Data and Information System (EOSDIS).

Created by: Land, Atmosphere Near real-time Capability for EOS (LANCE) for Fire Information for Resource Management System (FIRMS), NASA

Curated in GEE by : Samapriya Roy

Keywords: Archival fire, MODIS, VIIRS, Daytime, Nigh time, Thermal anomalies, FIRMS, LANCE, NASA, vector

Last updated: 2022-04-28

Last updated on GEE: 2022-04-28
